@@ -6,7 +6,7 @@ several values for the same key.
 """
 
 from ._abc import MultiMapping, MutableMultiMapping
-from ._compat import USE_CYTHON_EXTENSIONS
+from ._compat import USE_EXTENSIONS
 
 __all__ = (
     "MultiMapping",
@@ -17,28 +17,32 @@ __all__ = (
     "CIMultiDict",
     "upstr",
     "istr",
+    "getversion",
 )
 
-__version__ = "4.6.1"
+__version__ = "6.0.2"
 
 
 try:
-    if not USE_CYTHON_EXTENSIONS:
+    if not USE_EXTENSIONS:
         raise ImportError
     from ._multidict import (
-        MultiDictProxy,
+        CIMultiDict,
         CIMultiDictProxy,
         MultiDict,
-        CIMultiDict,
-        upstr,
+        MultiDictProxy,
+        getversion,
         istr,
     )
 except ImportError:  # pragma: no cover
     from ._multidict_py import (
-        MultiDictProxy,
+        CIMultiDict,
         CIMultiDictProxy,
         MultiDict,
-        CIMultiDict,
-        upstr,
+        MultiDictProxy,
+        getversion,
         istr,
     )
+
+
+upstr = istr
